@@ -3,7 +3,7 @@
 
      Laurence Lundblade <lgl@qualcomm.com>
 
-     Copyright 1997, QUALCOMM Inc.
+     Copyright (c) 2009 QUALCOMM Incorporated.
 
      File: lineend.h - deal with varying end of line conventions
      Version: 0.2.3, Dec 1997
@@ -13,7 +13,7 @@
 
 #ifndef _LINEENDINCLUDED
 #define _LINEENDINCLUDED
-#include <config.h>
+#include "config.h"
 extern const char *lineEnd;
 
 /*#undef UNIX */
