@@ -3,19 +3,19 @@
 
      Laurence Lundblade <lgl@qualcomm.com>
 
-     Copyright (c) 2005 QUALCOMM Incorporated.  All rights reserved.
+     Copyright (c) 2009 QUALCOMM Incorporated.  All rights reserved.
      The license.txt file specifies the terms for use, modification, and 
      redistribution.
 
      File: mangle.c - Functions called back by mime parser to do mangling
-     Version: 0.2.4, Jan 2001
-     Last Edited: Jan 29 08:20
    
      These are the call back functions we supply to the MIME parser. They
      implement all the specific handling of parts that reduced MIME down
      to plain text.
 
      Revisions:
+            Apr 24, 2008.  [rg]
+            - Fix crash if mangle string ended with header and no ")".
             Jun 20, 2000.  [rg]
             - Asking for an unsupported transormation (such as text/enriched)
               gets you text/plain.
@@ -763,6 +763,11 @@ int FillMangleInfo ( char *commandLine, char bNoContent,
                     p = q+1;
                     if(*q == ';' || *q == ')') break;
                 }
+                if ( q == NULL ) { /* we exited without finding terminator */
+                    DEBUGIT (( DBG_PRM, "Mangle header list didn't end with"
+                                 " semicolon or close paren" ));
+                    return -1;
+                }
             }
         }
     }
