@@ -3,7 +3,7 @@
 
      Laurence Lundblade <lgl@qualcomm.com>
 
-     Copyright 2000 QUALCOMM Incorporated.  All rights reserved.
+     Copyright (c) 2009 QUALCOMM Incorporated.  All rights reserved.
      The license.txt file specifies the terms for use, modification, and 
      redistribution.
 
@@ -52,7 +52,9 @@ To do:
   ---- */
      
 
+#include <sys/types.h>
 #include <stdio.h>
+#include <stdlib.h>
 #include <string.h>
 
 #ifdef HAVE_UNISTD_H
@@ -89,19 +91,19 @@ To do:
    Returns: the state/context to be passed to us
    --- */
 static void 
-MimeCteQPInit( OutputFn oFn, OutputFn oFnCtor, OutputFn oFnDtor, void *oFnState, 
-           MimeCtePtr state )
+MimeCteQPInit ( OutputFn oFn, OutputFn oFnCtor, OutputFn oFnDtor, void *oFnState, 
+                MimeCtePtr state )
 {
   state->outFn              = oFn;
-  state->outFnCtor              = oFnCtor;
-  state->outFnDtor              = oFnDtor;
+  state->outFnCtor          = oFnCtor;
+  state->outFnDtor          = oFnDtor;
   state->outFnState         = oFnState;
   state->x.QP.is2047        = 0;
   state->x.QP.lastWasEqual  = 0;
 }
 
 static void 
-MimeCte2047Init( MimeCtePtr state )
+MimeCte2047Init ( MimeCtePtr state )
 {
   state->outFn              = NULL;
   state->x.QP.is2047        = 1;
@@ -109,18 +111,23 @@ MimeCte2047Init( MimeCtePtr state )
 }
 
 static void MimeCteQPCtor ( MimeCtePtr cS, char *buffer, long bufferLen )  
-
 {
-    if(cS->outFnCtor)
-    (*cS->outFnCtor)(cS->outFnState, NULL, 0);
+    (void) buffer;
+    (void) bufferLen;
+
+    if ( cS->outFnCtor )
+        (*cS->outFnCtor) ( cS->outFnState, NULL, 0 );
 }
-static void MimeCteQPDtor( cS, buffer, bufferLen )  
+static void MimeCteQPDtor ( cS, buffer, bufferLen )  
 MimeCtePtr cS;
 char *buffer;
 long  bufferLen;
 {
-    if(cS->outFnDtor)
-    (*cS->outFnDtor)(cS->outFnState, NULL, 0);
+    (void) buffer;
+    (void) bufferLen;
+
+    if ( cS->outFnDtor )
+        (*cS->outFnDtor) ( cS->outFnState, NULL, 0 );
 }
 
 
@@ -139,23 +146,26 @@ long  bufferLen;
    Note: this code ignores the bufferLen, and expects input to be
          NULL terminated (which is supplied by input buffering).
    ---- */
-static void MimeCteQPProcess( cS, buffer, bufferLen )  
+static void MimeCteQPProcess ( cS, buffer, bufferLen )  
 MimeCtePtr cS;
 char *buffer;
 long  bufferLen;
 {
-  char *i, *o;
+    char *i, *o;
+    (void) buffer;
+    (void) bufferLen;
 
-  if( buffer == NULL ) {
-    /* Called with NULL flush and close; We have no buffering.. */
-    if(cS->outFn)
-      (cS->outFn)(cS->outFnState, NULL, 0);
+
+  if ( buffer == NULL ) {
+    /* Called with NULL flush and close; We have no buffering. */
+    if ( cS->outFn )
+      (cS->outFn) ( cS->outFnState, NULL, 0 );
     return;
   }
 
 
-  for(i = buffer, o = buffer;  *i; ) {
-    if(*i == '=' || cS->x.QP.lastWasEqual) {
+  for (i = buffer, o = buffer;  *i; ) {
+    if ( *i == '=' || cS->x.QP.lastWasEqual ) {
       /* --- It's an escaped sequence we have to treat special --- */
       cS->x.QP.lastWasEqual = 0;
       if(*i == '=')
@@ -271,7 +281,7 @@ MimeCteType *cS;
 
    Returns: the state/context to be passed to us
    --- */
-static MimeCteB64Init( OutputFn *oFn, OutputFn *oFnCtor, OutputFn *oFnDtor, void *oFnState, 
+static void MimeCteB64Init( OutputFn *oFn, OutputFn *oFnCtor, OutputFn *oFnDtor, void *oFnState, 
                MimeCtePtr state )
 {
   state->outFn            = oFn;
@@ -636,7 +646,9 @@ char             isContinuation;  /*This is a complete, or the completion*/
                     hState->parseState = wantParamName;
                 break;
             case wantParamName:
-                for ( paramType = paramMax-1; paramType != paramNone; paramType-- )
+                for ( paramType = (MimeParamKind) paramMax-1; 
+                      paramType != paramNone; 
+                      paramType-- )
                     if ( !StrCompare(tempBuf, Params[paramType]) ) {
                         hState->lexState.dontDownCase = ParamCaseMap[paramType];
                         break;
@@ -671,6 +683,8 @@ char             isContinuation;  /*This is a complete, or the completion*/
             case wantNothing:
                 /* Ignore the rest of the stuff */
                 break;
+            default:
+                break;
         } /* switch hState->parseState */
     }
     return;
@@ -768,8 +782,6 @@ MimeParseType *s;
         s->cteHandlerConstructor = s->cteHandlerDestructor = NULL;
         s->outputTag = outputNone;
     } else {
-        s->cteHandlerConstructor = s->cteHandlerDestructor = NULL;
-        s->outputTag = outputCTE;
         switch ( s->mType.cte ) {
             case cteBinary:
             case cte7bit:
@@ -781,6 +793,7 @@ MimeParseType *s;
                 s->outState.oFnState     = outFnState;
                 break;
             case cteQP:
+                s->outputTag             = outputCTE;
                 s->output.cteHandler     = MimeCteQPProcess;
                 s->cteHandlerConstructor = (OutputFn*) MimeCteQPCtor;
                 s->cteHandlerDestructor  = (OutputFn*) MimeCteQPDtor;
@@ -788,12 +801,18 @@ MimeParseType *s;
                       &(s->outState.cteState));
                 break;
             case cteBase64:
+                s->outputTag             = outputCTE;
                 s->output.cteHandler     = MimeCteB64Process;
                 s->cteHandlerConstructor = (OutputFn*) MimeCteB64Ctor;
                 s->cteHandlerDestructor  = (OutputFn*) MimeCteB64Dtor;
                 MimeCteB64Init ( outFn, outFnConstructor, outFnDestructor, 
                                  outFnState, 
                                  &(s->outState.cteState) );
+                break;
+            default:
+                s->cteHandlerConstructor = s->cteHandlerDestructor = NULL;
+                s->outputTag             = outputCTE;
+                break;
         } /* switch s->mType.cte */
     } /* outFn isn't NULL and mError is merrorNone */
 }
@@ -822,7 +841,7 @@ char          *inBuf;
 short          inBufLen;
 {
   char       *i, *b, hasEOL;
-  int         l;
+  int         l = 0;
 
   i = inBuf;
 
@@ -832,9 +851,9 @@ short          inBufLen;
       /* flush a new line we might have (only buffering here) */
       char temp[EOLLEN+1];
       StrCopy(temp, lineEnd);
-      if(State->outputTag == outputCTE)
+      if ( State->outputTag == outputCTE )
         (*State->output.cteHandler)(&(State->outState.cteState), temp, EOLLEN);
-      else
+      else if ( State->outputTag != outputNone )
         (*State->output.outHandler)(State->outState.oFnState, temp, EOLLEN);          
     }
     /* Call output function with NULL to let them know to shutdown */
@@ -903,7 +922,7 @@ short          inBufLen;
 
     /* --- Check for closing boundary --- */
     l = StrLen(State->mimeBoundaries[l]);
-    if(StrLen(inBuf) >= 4+l && inBuf[2+l] == '-' && inBuf[3+l] == '-') {
+    if ( StrLen(inBuf) >= (size_t) 4+l && inBuf[2+l] == '-' && inBuf[3+l] == '-' ) {
       /* See if we are in LookAHead at the current level. */
       if( State->multAttribs.attribs[State->multAttribs.nestLevel].LookAHead == 1 ) {
       /* Try to recreate the state */
