@@ -3,11 +3,15 @@
  *
  * A change-password server.
  *
- * Copyright (c) 2002 QUALCOMM Incorporated.  All rights reserved.
+ * Copyright (c) 2009 QUALCOMM Incorporated.  All rights reserved.
  * The file license.txt specifies the terms for use, modification,
  * and redistribution.
  *
  * Revisions:
+ *
+ *   05/02/03 [RCG]
+ *      - Now running smbpasswd as user, not root, to avoid exploit
+ *
  *   05/06/01 [RCG]
  *      - Changed UID check to be the same as Qpopper's (which is
  *        that if BLOCK_UID is defined we use that value, otherwise
@@ -594,14 +598,15 @@ int main ( int argc, char *argv[] )
 
     if ( strlen (newpass) > PASSWD_LENGTH )
     {
-        WriteToClient ( "500 New password is too long; limited to %d characters", PASSWD_LENGTH);
+        WriteToClient ( "500 New password is too long; limited to %d characters",
+                        PASSWD_LENGTH );
         return 1;
     }
          
     if ( mode & RUN_PASSWD )
         runchild ( userid, oldpass, newpass, 0 );
 
-    if (mode & RUN_SMBPASSWD)
+    if ( mode & RUN_SMBPASSWD )
         runchild ( userid, oldpass, newpass, 1 );
 
     /* all done */
@@ -701,7 +706,7 @@ void runchild ( char *userid, char *oldpass, char *newpass, int smb )
 /*
  * dochild
  *
- * Do child stuff - set up slave pty and execl as needed
+ * Do child stuff -- set up slave pty and execl as needed
  *
  * Code adapted from "Advanced Programming in the UNIX Environment"
  * by W. Richard Stevens.
@@ -713,7 +718,7 @@ int dochild (int master, char *slavedev, char *userid, int smb)
    int slave;
    struct termios stermios;
 
-   /* Start new session - gets rid of controlling terminal. */
+   /* Start new session -- gets rid of controlling terminal. */
    
    if (setsid() < 0) {
       err_msg ( HERE, "setsid failed" );
@@ -792,7 +797,10 @@ int dochild (int master, char *slavedev, char *userid, int smb)
    else
    {
      TRACE ( trace_file, POP_DEBUG, HERE, "...changing smb password" );
-     execl ( smb_binary, "smbpasswd", userid, NULL );
+     setregid ( pw->pw_gid, pw->pw_gid );
+     setreuid ( pw->pw_uid, pw->pw_uid );
+
+     execl ( smb_binary, "smbpasswd", NULL );
 
      err_msg ( HERE, "can't exec %s", smb_binary );
      exit ( 1 );
