@@ -5,6 +5,9 @@
  *
  * Revisions:
  *
+ *    07/12/09   [rg]
+ *              - Stop using sys_nerr and sys_errlist.
+ *
  *     04/25/05  [rcg]
  *              - Fix '-V' for standalone.
  *
@@ -871,9 +874,9 @@ sys_err_str()
     static char msgstr [ 200 ];
     if ( errno != 0 )
     {
-        if ( errno > 0 && errno < sys_nerr )
+        if ( errno > 0 )
             Qsnprintf ( msgstr, sizeof(msgstr), "(%d) %s", 
-                        errno, sys_errlist [ errno ] );
+                        errno, STRERROR ( errno ) );
         else
             Qsnprintf ( msgstr, sizeof(msgstr), "errno = %d", errno );
 
