@@ -2,7 +2,7 @@
  * SASL authentication mechanisms for qpopper
  *
  * File:      pop_auth.c
- * Copyright: (c) 2000 QUALCOMM Incorporated.  All rights reserved.
+ * Copyright: (c) 2003 QUALCOMM Incorporated.  All rights reserved.
  *            The file license.txt specifies the terms for use,
  *            modification, and redistribution.
  */
@@ -10,6 +10,30 @@
 /*
  * Revisions:
  *
+ *     08/13/03  [rcg]
+ *             - Patch from Uli Zappe to fix SCRAM compilation bugs.
+ *
+ *     01/29/01  [rcg]
+ *             - Now using p->grp_serv_mode and p->grp_no_serv_mode instead
+ *               of SERVER_MODE_GROUP_INCLUDE and SERVER_MODE_GROUP_EXCLUDE.
+ *             - Now using p->authfile instead of AUTHFILE.
+ *
+ *     11/14/00  [rcg]
+ *             - Now trimming domain name only if requested.
+ *
+ *     10/02/00  [rcg]
+ *             - Now calling check_config_files to check qpopper-options files.
+ *
+ *     09/09/00  [rcg]
+ *             - Now stripping domain name from user name.
+ *
+ *     06/30/00  [rcg]
+ *             - Added support for ~/.qpopper-options.
+ *
+ *     06/16/00  [rcg]
+ *              - Now setting server mode on or off based on group
+ *                membership.
+ *
  *    05/01/00  [rcg]
  *              - Somehow a call to pop_msg was passing &p instead of p.
  *
@@ -53,7 +77,6 @@
 #include <ctype.h>
 #include <flock.h>
 
-#include "genpath.h"
 #include "popper.h"
 
      /* Need the following stuff iff SCRAM is being compiled */
@@ -82,11 +105,13 @@ static struct passwd    * pw;
 
 #endif  /* ifdef SCRAM */
 
+extern char    *ERRMSG_PW;
+
 static auth_table mechanisms[] = {
 #ifdef SCRAM
-    "scram-md5", pop_scram,
+    { "scram-md5", pop_scram, },
 #endif
-    NULL,        NULL
+    { NULL,        NULL }
 };
 
     /*  Process the Auth Command Initiation */
@@ -97,14 +122,17 @@ POP     *   p;
     auth_table *a;
 
     /* Auth with no args spills the list of supported mechanisms */
-    if ( !p->parm_count ) {
-        pop_msg(p,POP_SUCCESS, HERE,"Following are Supported SASL mechanisms");
-        for (a = mechanisms; a->auth_mechanism; a++) {
-            (void)fprintf(p->output, "%s\r\n",a->auth_mechanism);
+    if ( p->parm_count == 0 ) {
+        pop_msg ( p, POP_SUCCESS, HERE, "Supported SASL mechanisms:" );
+        if ( mechanisms[0].auth_mechanism == NULL )
+            pop_write_line ( p, "X-NONE-SO-USE-APOP-OR-STLS" );
+        else
+        for ( a = mechanisms; a->auth_mechanism; a++ ) {
+            pop_write_line(p, a->auth_mechanism);
         }
-        (void)fputs(".\r\n",p->output);
-        (void)fflush(p->output);
-        return( POP_FAILURE );
+        pop_write_line  ( p, "." );
+        pop_write_flush ( p );
+    return ( POP_FAILURE );
     }
 
     /* Process SCRAM Initiation */
@@ -147,15 +175,15 @@ int pop_scram( p )
     char    *msg;
     static int     stSize = sizeof(authcntl)/sizeof(authcntl[0]);
     if(p->AuthState = none) {
-        p->AuthType    = scram_md5;
-        p->AuthState   = auth;
-        if ( p->parm_count == 1 ) {
-            fprintf( p->output, "+ %s", EOL );
-            fflush( p->output );
-            Push(&(p->InProcess), (FP)pop_scram);
-            return( POP_SUCCESS );
-        }
-        msg = p->pop_parm[2];
+    p->AuthType    = scram_md5;
+    p->AuthState   = auth;
+    if ( p->parm_count == 1 ) {
+            pop_write_line(p, "+ ");
+            pop_write_flush(p);
+        Push(&(p->InProcess), (FP)pop_scram);
+        return( POP_SUCCESS );
+    }
+    msg = p->pop_parm[2];
     }
     else {
         int i;               /* SCRAM-MD5 authentication phase */
@@ -301,19 +329,19 @@ static int pop_client_challenge( p, msg )
 
 
      /* Downcase user name if requested */
-  if (p->downcase_user)
+  if ( p->bDowncase_user )
     downcase_uname(p, p->user);
 
+    /* Strip domain name if requested */
+  if ( p->bTrim_domain )
+    trim_domain(p, p->user);
+
      /* Get rid of the unauthorized and the excluded */
 
   if ( *p->authid == '\0'
-#ifdef AUTHFILE
-       || (checkauthfile(p->user) != 0)
-#endif
-#ifdef NONAUTHFILE
-       ||  (*p->authid && checknonauthfile(p->user) != 0)
-#endif
-                 )
+       || ( p->authfile    != NULL && checkauthfile    ( p ) != 0 )
+       || ( p->nonauthfile != NULL && checknonauthfile ( p ) != 0 )
+     )
   {
 #ifdef NOHINT
     *p->authid = '\0';
@@ -326,15 +354,16 @@ static int pop_client_challenge( p, msg )
 
     /* Blow away everyone who UNIX knows nothing about */
 
+  pw = &(p->pw);
   if ( *p->authid &&
-        (((pw = getpwnam (p->user)) == NULL) || (pw->pw_passwd == NULL)
+        ((pw == NULL) || (pw->pw_passwd == NULL)
           || (*pw->pw_passwd == '\0')) )
   {
 #ifdef NOHINT
    *p->authid = '\0';
     strcpy( outbuf, "UNIX password system rejection." );
 #else
-    return ( pop_auth_fail ( p, POP_FAILURE, HERE, pwerrmsg, p->user) );
+    return ( pop_auth_fail ( p, POP_FAILURE, HERE, ERRMSG_PW, p->user) );
 #endif
   }
 
@@ -642,12 +671,10 @@ fflush( stdout );
  ***/
 
 
-  if ( fprintf( p->output, "+ %s%s", outbuf, EOL )
-             != (2+outlen+strlen(EOL)) )
-    return( pop_msg(p,POP_FAILURE, HERE,
-              "Can't get out server challenge") );
+  pop_write(p, "+ ", 2);
+  pop_write_line(p, outbuf);
+  pop_write_flush(p);
 
-  fflush( p->output );
 
 #ifdef INTERNAL_TEST
   if ( strcmp( outbuf, tsmess) )
@@ -742,12 +769,9 @@ static int pop_client_response( p, msg )
 
   outbuf[ outlen ] = '\0';
   
-  if ( fprintf( p->output, "+ %s%s", outbuf, EOL )
-             != (2+outlen+strlen(EOL)) )
-    return( pop_msg(p,POP_FAILURE, HERE,
-              "Can't get out server proof") );
-
-  fflush( p->output );
+  pop_write(p, "+ ", 2);
+  pop_write_line(p, outbuf);
+  pop_write_flush(p);
 
   DEBUG_LOG1(p,"SCRAM-MD5 client authentication ok for \"%s\"", p->user);
 
@@ -784,23 +808,44 @@ static int pop_client_ok( p, msg )
 #endif
 
 
-    /* Do regular drop stuff */
+    /*
+     * Check if server mode should be set or reset based on group membership.
+     */
 
-    if ( genpath ( p->user, 
-                   p->drop_name, 
-                   sizeof(p->drop_name), 
-                   GNPH_SPOOL,
-                   (p->debug ? p->trace : NULL),
-                   p->debug ) < 0 )
-        return(pop_msg(p, POP_FAILURE, HERE, "Unable to create temporary drop name"));
+    if ( p->grp_serv_mode != NULL
+         && check_group ( p, pw, p->grp_serv_mode ) ) {
+        p->server_mode = TRUE;
+        DEBUG_LOG2 ( p, "Set server mode for user %s; "
+                        "member of \"%.128s\" group",
+                     p->user, p->grp_serv_mode );
+    }
 
-    /*  Make a temporary copy of the user's maildrop */
-    /*    and set the group and user id */
-    if (pop_dropcopy(p, pw) != POP_SUCCESS) return (POP_FAILURE);
+    if ( p->grp_no_serv_mode != NULL
+         && check_group ( p, pw, p->grp_no_serv_mode ) ) {
+        p->server_mode = FALSE;
+        DEBUG_LOG2 ( p, "Set server mode OFF for user %s; "
+                        "member of \"%.128s\" group",
+                     p->user, p->grp_no_serv_mode );
+    }
+
+    /*
+     * Process qpopper-options files, if requested and present.
+     */
+    check_config_files ( p, pw );
+
+    /*
+     * Make a temporary copy of the user's maildrop
+     * and set the group and user id
+     */
+    if ( pop_dropcopy ( p, pw ) != POP_SUCCESS ) 
+        return ( POP_FAILURE );
 
     /*  Initialize the last-message-accessed number */
     p->last_msg = 0;
 
+    if ( p->pLog_login != NULL )
+        do_log_login ( p );
+
     /*  
      * Authorization completed successfully: final server authentication action 
      */
