@@ -6,6 +6,9 @@
 
 
 /* Changes:
+ *
+ *   03/04/09  [rcg]
+ *            - Use Qsnprintf instead of sprintf
  *
  *   02/08/01  [rcg]
  *            - Now using p->nMaxBulls instead of NEWBULLCNT.
@@ -695,15 +698,16 @@ extern int newline; /* lives in pop_dropcopy.c */
 int
 CopyOneBull ( POP *p, long bnum, char *name )
 {
-    FILE          *bull;
+    FILE          *bull                 = NULL;
     char           buffer [ MAXMSGLINELEN ];
     BOOL           in_header            = TRUE;
     BOOL           first_line           = TRUE;
-    int            nchar;
-    int            msg_num;
+    int            nchar                = 0;
+    int            nbullname            = 0;
+    int            msg_num              = -1;
     int            msg_vis_num          = 0;
     int            msg_ends_in_nl       = 0;
-    char           bullName [ 256 ];
+    char           bullName [ MAXFILENAME ];
     MsgInfoList   *mp;               /* Pointer to message info list */
 
 
@@ -717,7 +721,18 @@ CopyOneBull ( POP *p, long bnum, char *name )
     msg_num = p->msg_count;
     p->msg_count = ( ( ( p->msg_count - 1 ) / ALLOC_MSGS ) + 1 ) * ALLOC_MSGS;
 
-    sprintf ( bullName, "%s/%s", p->bulldir, name );
+    nbullname = Qvsnprintf ( bullName, sizeof(bullName),
+                             "%s/%s", p->bulldir, name );
+    if ( nbullname == -1 ) {
+        pop_log ( p, POP_PRIORITY, HERE,
+                 "Bulletin directory + file name too long; "
+                 "directory (%d): \"%.100s\"; "
+                 "file name (%d): \"%.100s\" ", 
+                 strlen(p->bulldir), p->bulldir,
+                 strlen(name), name );
+       return POP_FAILURE;
+    }
+    
     bull = fopen ( bullName, "r" );
     if ( bull == NULL ) {
        pop_log ( p, POP_PRIORITY, HERE,
