@@ -13,6 +13,9 @@
  *
  * Revisions:
  *
+ * 03/04/09  [rcg]
+ *          - Use Qsnprintf instead of sprintf
+ *
  * 08/13/01  [dts]
  *          - set hangup = TRUE in pop_write_now() and pop_write_flush()
  *            in the event of an I/O error.
@@ -178,7 +181,8 @@ static void header_mucker_input(
               strncasecmp ( input, "Status:", 7 ) == 0
             )
        ) {
-        sprintf ( uidl_buf, "X-UIDL: %s", hm_state->uidl_str );
+        Qsnprintf ( uidl_buf, sizeof(uidl_buf), "X-UIDL: %s",
+                   hm_state->uidl_str );
         ( *(hm_state->out_fn) ) ( hm_state->out_state, uidl_buf, strlen(uidl_buf) );
         hm_state->uidl_sent = TRUE;
     }
