@@ -5,7 +5,7 @@
  */
 
 /*
- * Copyright (c) 2005 QUALCOMM Incorporated.  All rights reserved.
+ * Copyright (c) 2009 QUALCOMM Incorporated.  All rights reserved.
  * The file License.txt specifies the terms for use, modification,
  * and redistribution.
  */
@@ -15,6 +15,9 @@
  *
  * Revisions:
  *
+ *  09/24/09 [rg]
+ *           - Rename 'getline' to avoid conflict on some platforms.
+ *
  *  12/04/04 [rg]
  *           - Applied patch from David Shrimpton to unblock sigalarm
  *             before alarm signal handler is changed.  This is really
@@ -150,7 +153,7 @@ char        **  argv;
     char                message [ MAXLINELEN ];
     pop_result          rslt = POP_FAILURE;
     char            *   tgetline();
-    char            *   getline();
+    char            *   Qgetline();
     
     /*
      * seed random with the current time to nearest second 
@@ -425,7 +428,7 @@ jmp_buf env;
  */
 
 char
-*getline ( char *str, int size, POP *pPOP )
+*Qgetline ( char *str, int size, POP *pPOP )
 {
     char *p       = NULL;
     int   nRead   = 0;
@@ -433,7 +436,7 @@ char
     int   nBufSz  = sizeof ( pPOP->pcInBuf );
 
 
-    _DEBUG_LOG2 ( pPOP, "getline(%p,%d)", str, size );
+    _DEBUG_LOG2 ( pPOP, "Qgetline(%p,%d)", str, size );
 
     /*
      * See if there's a line in our input buffer
@@ -472,7 +475,7 @@ char
                               pPOP->pcInStart - pPOP->pcInBuf );
                 pPOP->pcInStart = pPOP->pcInEnd = pPOP->pcInBuf;
             }
-            _DEBUG_LOG3 ( pPOP, "getline() returning %d: '%.*s'",
+            _DEBUG_LOG3 ( pPOP, "Qgetline() returning %d: '%.*s'",
                           strlen(str), MIN(25, (int) strlen(str)), str );
             return ( str );
         } /* got a line */
@@ -560,7 +563,7 @@ char
                 } /* found a '\n' */
             } /* loop and discard until we see a '\n' */
 
-            _DEBUG_LOG2 ( pPOP, "getline() returning %d ('%c')",
+            _DEBUG_LOG2 ( pPOP, "Qgetline() returning %d ('%c')",
                           strlen(str), *str );
             return ( str );
         } /* nRoom == 0 */
@@ -583,7 +586,7 @@ char
             break;
     } /* main loop */
 
-    _DEBUG_LOG0 ( pPOP, "getline() returning NULL" );
+    _DEBUG_LOG0 ( pPOP, "Qgetline() returning NULL" );
     return ( NULL );
 }
 
@@ -614,7 +617,7 @@ tgetline ( char *str, int size, POP *p, int timeout )
                   VERSION, timeout, p->user, p->client, p->ipaddr );
     }
     else
-        str = getline ( str, size, p );
+        str = Qgetline ( str, size, p );
 
     alarm  ( 0 );
     signal ( SIGALRM, SIG_DFL );
